lambda_hvl = 193; % Skala for HVL 2019-modell
lambda_dtc = 59.407; % Skala DTC ved Strasburg
ms_to_kn = 1.943844; % M/s til knop
kn_to_ms = 0.5144444; % Knop til m/s

%% Full skala data
Ls = 355; % Lenge skrog fullskala
Ss = 22032; % Vtoverflateareal fullskala
nabla_s = 173467; % Volumdeplasement fullskala
Vsd = 25/kn_to_ms; % Fart fullskala
ks = 0.145; % Formfaktor fra RANS DTC-test

rho_s = 1026; % Tetthet sjvann 15 grader (ITTC) [kg/m^3]
nu_s = 1.1892E-06; % Kinematisk visksitet sjvann 15 grader (ITTC) [m^2/s]

%% 2019-modell
Lm = Ls/lambda_hvl; % Lengde modell
Sm = Ss/lambda_hvl.^2; % Vtoverflate modell
nabla_m = nabla_s/lambda_hvl.^3; % Volumdeplasement modell
Vmd = Vsd/sqrt(lambda_hvl); % Fart modell
rho_m = 999; % Tetthet ferskvann ved 14 grader
delta_m = nabla_m*rho_m; % Deplasement modell
nu_m = 1.1692E-06; % Kinematisk visksitet ferskvann 14 grader 

%% DTC SVA modell
Lm_dtc = Ls/lambda_dtc; % Lengde modell SVA
Sm_dtc = Ss/lambda_dtc.^2; % Vtoverflate modell SVA
nabla_dtc = nabla_s/lambda_dtc.^3; % Volumdeplasement modell SVA
rho_dtc = 998.8; % Tetthet vann SVA
delta_dtc = nabla_dtc*rho_dtc; % Deplasement modell SVA
nu_dtc = 1.090E-06; % Kinematisk visksitet modell SVA
k_dtc = 0.094; % Formfaktor fra SVA rapport
%% SVA resultat
A =[1.335 0.174 7.319 20.34 17.611 3.661 3.170 1.932
   1.401 0.183 7.681 22.06 19.229 3.605 3.142 1.672
   1.469 0.192 8.054 24.14 20.964 3.588 3.116 1.791
   1.535 0.200 8.415 26.46 22.713 3.602 3.092 2.194
   1.602 0.209 8.783 28.99 24.554 3.623 3.069 2.660
   1.668 0.218 9.145 31.83 26.431 3.670 3.047 3.360]; % Resultatene fra SVA modell testing, hentet fra rapport
Vm_dtc = A(:,1); % Modell fart
Rtm_dtc = A(:,4); % Modell motstand
Re_dtc = A(:,3)/10E-06; % Reynolds tall modell SVA
Fn_dtc = A(:,2); % Froudes tall modell SVA
Rfm_dtc = A(:,5); % Friksjonsmotstand modell SVA
Ctm_dtc = A(:,6)/10^(3); % Totalmotstands komponent modell SVA
Cfm_dtc = A(:,7)/10^(3); % Friksjonsmotstands komponent modell SVA
Cwm_dtc = A(:,8)/10^(4); % Blgemotstands komponent modell SVA

Vs_dtc = Vm_dtc.*sqrt(lambda_dtc);
Res_dtc = (Vs_dtc.*Ls)./nu_s;
Cfs_dtc = 0.075./((log10(Res_dtc)-2).^2); % Friksjonsmotstands komponent for fullskala skip SVA
Cvs_dtc = (1+0.094)*Cfs_dtc; % Visksmotstands komponent for fullskala skip SVA
Cts_dtc = Cvs_dtc + Cwm_dtc; % Totalmotstands komponent for fullskala skip SVA

Rts_dtc=0.5.*rho_s.*Vs_dtc.^2.*Ss.*Cts_dtc; % Totalmotstand [N] SVA
Rfs_dtc=0.5.*rho_s.*Vs_dtc.^2.*Ss.*Cfs_dtc; % Friksjonsotstand [N] SVA
Rvs_dtc=0.5.*rho_s.*Vs_dtc.^2.*Ss.*Cvs_dtc; % Visksmotstand [N] SVA
Rws_dtc=0.5.*rho_s.*Vs_dtc.^2.*Ss.*Cwm_dtc; % % Blgemotstand [N] SVA
%% HVL-resultat
Vm = [0 0.1 0.15 0.2 0.3 0.4 0.5 0.6 0.7 0.738 0.776 0.814 0.848 0.886 0.925];
Rtm = [0.000000 0.011700 0.043120 0.070300 0.154500 0.268700 0.390200 0.556200 0.731700 0.792900 0.873600 0.960300 1.039000 1.154000 1.274000];

% Finner blgemotstanden Cw 
Fr = Vm./(sqrt(9.81.*Lm)); % Froudes tall modell HVL
Ctm = Rtm./(0.5.*rho_m.*Sm.*Vm.^2); % Totalmotstands komponent modell HVL
Rem = (Vm*Lm)./nu_m; % Reynoldstallet for modell HVL
Cfm = 0.075./((log10(Rem)-2).^2); % Friksjonsmotstands komponent modell HVL
Fn4Cfm = Fr.^4./Cfm;
CtmCfm = Ctm./Cfm;
ind1 = find(Fr>=0.05);
ind2 = find(Fr>=0.15);
    if isempty(ind1)==1
        fprintf('Lower froude number limit 0.05 does not exist, use Froude method.')
        return
    end
    if isempty(ind2)==1
        fprintf('Upper froude number limit 0.15 does not exist, use Froude method.')
        return
    end
fs = ind1(1);
fe = ind2(2);
p = polyfit(Fn4Cfm(fs:fe),CtmCfm(fs:fe),1);
yfit = polyval(p,Fn4Cfm);
figure(1)
plot(Fn4Cfm,CtmCfm,Fn4Cfm,yfit,'x--','LineWidth',1.5)
hx = xlabel('Fn^4/Cfm');
hy = ylabel('Ctm/Cfm');
hl = legend('Prohaskas metode', 'Regresjons linje', 'location','se');
n = int32(length(yfit)/2); % for text placement y=ax+b
text(Fn4Cfm(n),yfit(n)-0.1,['y= ' num2str(p(1)) 'x+' num2str(p(2)) '.'])
    
r = p(2);  % r=b in y=ax+b of regression line in Prohaska method;
k = r-1;
fprintf('\nProhaska method used, r=%.2f, k=%.2f.\n',r, k)
fprintf('Regression line should be calculated between 0.05 < Fr < 0.15.\n' )
fprintf('Resulting interval is: %.2f < Fr < %.2f.\n',Fr(fs), Fr(fe))
saveas (1,'Formfaktor.png')
Cvm = (1+k)*Cfm; % Visksmotstands komponent modell HVL
Cw = Ctm - Cvm; % Blgemotstands komponent; lik for modell og skip

% Over til fullskala skip
Vs = Vm.*sqrt(lambda_hvl); % Fullskala fart [m/s]
Res = (Vs*Ls)./(1.1892E-06); % Reynoldstallet for fullskala skip
Cfs = 0.075./((log10(Res)-2).^2); % Friksjonsmotstands komponent for fullskala skip
Cvs = (1+k)*Cfs; % Visksmotstands komponent for fullskala skip
Cts = Cvs + Cw; % Totalmotstands komponent for fullskala skip

Rts=0.5.*rho_s.*Vs.^2.*Ss.*Cts; % Totalmotstand [N]
Rfs=0.5.*rho_s.*Vs.^2.*Ss.*Cfs; % Friksjonsotstand [N]
Rvs=0.5.*rho_s.*Vs.^2.*Ss.*Cvs; % Visksmotstand [N]
Rws=0.5.*rho_s.*Vs.^2.*Ss.*Cw; % % Blgemotstand [N]

Cr = Ctm-Cfm;
Cts_f = Cfs+Cr;
Rts_f = 0.5.*rho_s.*Vs.^2*Ss.*Cts_f;

% Slepeeffekt
Pe = Rts.*Vs;
Pe_f = Rts_f.*Vs;
Pe_dtc = Rts_dtc.*Vs_dtc;
%% Figurer
figure (2) % Fart og motstand
plot (Vm,Rtm,'LineWidth',1.5)
xlabel ('Hastighet [m/s]')
ylabel ('Motstand [N]')
saveas (2, 'Fart og motstand.png')

figure (3)
plot (Fr,Cts,Fr,Ctm,'LineWidth',1.5)
xlabel ('Froudes tall')
ylabel ('Totalmotstandskomponent')
legend ('Totalmotstand skip','Totalmotstand modell','Location','se')
saveas (3, 'Motstandskomponenter.png')

figure (4)
plot (Fr,Rts,'r--', Fr, Rts_f,'LineWidth',1.5)
xlabel ('Froudes tall')
ylabel ('Motstand [N]')
legend ('Prohaska','Froudes','Location','nw')
saveas (4, 'Froude vs prohaska.png')

figure (5)
plot (Vs, Pe,'r--',Vs,Pe_f,'LineWidth',1.5)
xlabel ('Hastighet [m/s]')
ylabel ('Effekt [w]')
legend ('Prohaska','Froudes','Location','nw')
saveas (5, 'Froude vs prohaska slepeeffekt.png')

figure(6)
plot(Vs_dtc,Rts_dtc,'r--',Vs,Rts,'LineWidth',1.5)
xlabel('Hastighet [m/s]')
ylabel('Motstand [N]')
legend ('DTC Fullskala skip', 'HVL Fullskala skip','Location','nw')
saveas (6, 'Fullskala motstand.png')

figure (7)
plot (Vs_dtc,Pe_dtc,'r--',Vs,Pe,'LineWidth',1.5)
xlabel ('Hastighet [m/s]')
ylabel ('Effekt [w]')
legend ('DTC Fullskala skip','HVL Fullskala skip')
saveas (7, 'Slepeffekt.png')